All of lore.kernel.org
 help / color / mirror / Atom feed
From: Biju Das <biju.das.jz@bp.renesas.com>
To: cip-dev@lists.cip-project.org,
	Nobuhiro Iwamatsu <nobuhiro1.iwamatsu@toshiba.co.jp>,
	Pavel Machek <pavel@denx.de>
Cc: Biju Das <biju.das.jz@bp.renesas.com>,
	Lad Prabhakar <prabhakar.mahadev-lad.rj@bp.renesas.com>
Subject: [PATCH 5.10.y-cip 01/25] drm/bridge: Add a function to abstract away panels
Date: Thu,  7 Dec 2023 14:24:38 +0000	[thread overview]
Message-ID: <20231207142502.401651-2-biju.das.jz@bp.renesas.com> (raw)
In-Reply-To: <20231207142502.401651-1-biju.das.jz@bp.renesas.com>

From: Maxime Ripard <maxime@cerno.tech>

commit 87ea95808d53e56b03e620e8f8f3add48899a88d upstream.

Display drivers so far need to have a lot of boilerplate to first
retrieve either the panel or bridge that they are connected to using
drm_of_find_panel_or_bridge(), and then either deal with each with ad-hoc
functions or create a drm panel bridge through drm_panel_bridge_add.

In order to reduce the boilerplate and hopefully create a path of least
resistance towards using the DRM panel bridge layer, let's create the
function devm_drm_of_get_bridge() to reduce that boilerplate.

Signed-off-by: Maxime Ripard <maxime@cerno.tech>
Reviewed-by: Sam Ravnborg <sam@ravnborg.org>
Link: https://patchwork.freedesktop.org/patch/msgid/20210910130941.1740182-2-maxime@cerno.tech
Signed-off-by: Biju Das <biju.das.jz@bp.renesas.com>
---
 drivers/gpu/drm/drm_bridge.c | 42 ++++++++++++++++++++++++++++++++----
 drivers/gpu/drm/drm_of.c     |  3 +++
 include/drm/drm_bridge.h     |  2 ++
 3 files changed, 43 insertions(+), 4 deletions(-)

diff --git a/drivers/gpu/drm/drm_of.c b/drivers/gpu/drm/drm_of.c
index 997b8827fed2..37c34146eea8 100644
--- a/drivers/gpu/drm/drm_of.c
+++ b/drivers/gpu/drm/drm_of.c
@@ -231,6 +231,9 @@ EXPORT_SYMBOL_GPL(drm_of_encoder_active_endpoint);
  * return either the associated struct drm_panel or drm_bridge device. Either
  * @panel or @bridge must not be NULL.
  *
+ * This function is deprecated and should not be used in new drivers. Use
+ * devm_drm_of_get_bridge() instead.
+ *
  * Returns zero if successful, or one of the standard error codes if it fails.
  */
 int drm_of_find_panel_or_bridge(const struct device_node *np,
diff --git a/include/drm/drm_bridge.h b/include/drm/drm_bridge.h
index 055486e35e68..3c640e704186 100644
--- a/include/drm/drm_bridge.h
+++ b/include/drm/drm_bridge.h
@@ -891,6 +891,8 @@ struct drm_bridge *devm_drm_panel_bridge_add(struct device *dev,
 struct drm_bridge *devm_drm_panel_bridge_add_typed(struct device *dev,
 						   struct drm_panel *panel,
 						   u32 connector_type);
+struct drm_bridge *devm_drm_of_get_bridge(struct device *dev, struct device_node *node,
+					  u32 port, u32 endpoint);
 struct drm_connector *drm_panel_bridge_connector(struct drm_bridge *bridge);
 #endif
 
diff --git a/drivers/gpu/drm/drm_bridge.c b/drivers/gpu/drm/drm_bridge.c
index d799ec14fd7f..f0f0a4efd200 100644
--- a/drivers/gpu/drm/drm_bridge.c
+++ b/drivers/gpu/drm/drm_bridge.c
@@ -28,6 +28,8 @@
 #include <drm/drm_atomic_state_helper.h>
 #include <drm/drm_bridge.h>
 #include <drm/drm_encoder.h>
+#include <drm/drm_of.h>
+#include <drm/drm_print.h>
 
 #include "drm_crtc_internal.h"
 
@@ -50,10 +52,8 @@
  *
  * Display drivers are responsible for linking encoders with the first bridge
  * in the chains. This is done by acquiring the appropriate bridge with
  * of_drm_find_bridge() or drm_of_find_panel_or_bridge(), or creating it for a
  * panel with drm_panel_bridge_add_typed() (or the managed version
  * devm_drm_panel_bridge_add_typed()). Once acquired, the bridge shall be
  * attached to the encoder with a call to drm_bridge_attach().
  *
  * Bridges are responsible for linking themselves with the next bridge in the
  * chain, if any. This is done the same way as for encoders, with the call to
@@ -1223,6 +1223,40 @@ struct drm_bridge *of_drm_find_bridge(struct device_node *np)
 	return NULL;
 }
 EXPORT_SYMBOL(of_drm_find_bridge);
+
+/**
+ * devm_drm_of_get_bridge - Return next bridge in the chain
+ * @dev: device to tie the bridge lifetime to
+ * @np: device tree node containing encoder output ports
+ * @port: port in the device tree node
+ * @endpoint: endpoint in the device tree node
+ *
+ * Given a DT node's port and endpoint number, finds the connected node
+ * and returns the associated bridge if any, or creates and returns a
+ * drm panel bridge instance if a panel is connected.
+ *
+ * Returns a pointer to the bridge if successful, or an error pointer
+ * otherwise.
+ */
+struct drm_bridge *devm_drm_of_get_bridge(struct device *dev,
+					  struct device_node *np,
+					  u32 port, u32 endpoint)
+{
+	struct drm_bridge *bridge;
+	struct drm_panel *panel;
+	int ret;
+
+	ret = drm_of_find_panel_or_bridge(np, port, endpoint,
+					  &panel, &bridge);
+	if (ret)
+		return ERR_PTR(ret);
+
+	if (panel)
+		bridge = devm_drm_panel_bridge_add(dev, panel);
+
+	return bridge;
+}
+EXPORT_SYMBOL(devm_drm_of_get_bridge);
 #endif
 
 MODULE_AUTHOR("Ajay Kumar <ajaykumar.rs@samsung.com>");
@@ -50,10 +52,8 @@
  * Display drivers are responsible for linking encoders with the first bridge
  * in the chains. This is done by acquiring the appropriate bridge with
- * of_drm_find_bridge() or drm_of_find_panel_or_bridge(), or creating it for a
- * panel with drm_panel_bridge_add_typed() (or the managed version
- * devm_drm_panel_bridge_add_typed()). Once acquired, the bridge shall be
- * attached to the encoder with a call to drm_bridge_attach().
+ * devm_drm_of_get_bridge(). Once acquired, the bridge shall be attached to the
+ * encoder with a call to drm_bridge_attach().
  *
  * Bridges are responsible for linking themselves with the next bridge in the
-- 
2.25.1



  reply	other threads:[~2023-12-07 14:25 UTC|newest]

Thread overview: 30+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-12-07 14:24 [PATCH 5.10.y-cip 00/25] Add RZ/G2L DSI support Biju Das
2023-12-07 14:24 ` Biju Das [this message]
2023-12-07 14:24 ` [PATCH 5.10.y-cip 02/25] drm/bridge: Add stubs for devm_drm_of_get_bridge when OF is disabled Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 03/25] drm/bridge: Move devm_drm_of_get_bridge to bridge/panel.c Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 04/25] drm: of: Add drm_of_get_data_lanes_count and drm_of_get_data_lanes_ep Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 05/25] drm: of: Mark empty drm_of_get_data_lanes_count and drm_of_get_data_lanes_ep static Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 06/25] dt-bindings: display: bridge: Document RZ/G2L MIPI DSI TX bindings Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 07/25] dt-bindings: display: bridge: renesas,rzg2l-mipi-dsi: Document RZ/V2L support Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 08/25] drm: rcar-du: Add RZ/G2L DSI driver Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 09/25] drm: rcar-du: Fix Kconfig dependency between DRM and RZG2L_MIPI_DSI Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 10/25] drm: rcar-du: rzg2l_mipi_dsi: Enhance device lanes check Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 11/25] drm: rcar-du: rzg2l_mipi_dsi: Reorder bridge attach Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 12/25] arm64: defconfig: Enable Renesas RZ/G2L MIPI DSI driver Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 13/25] arm64: dts: renesas: r9a07g044: Add DSI node Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 14/25] arm64: dts: renesas: r9a07g054: " Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 15/25] arm64: dts: renesas: rzg2l-smarc: Link DSI with ADV7535 Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 16/25] arm64: dts: renesas: rzg2lc-smarc: " Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 17/25] arm64: dts: renesas: Drop ADV7535 IRQ Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 18/25] arm64: dts: renesas: r9a07g044: [HACK DO NOT APPLY] Add DU node Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 19/25] arm64: dts: renesas: r9a07g054: " Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 20/25] arm64: dts: renesas: rzg2l-smarc: [HACK DO NOT APPLY] Enable DU and link with DSI Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 21/25] arm64: dts: renesas: rzg2lc-smarc: " Biju Das
2023-12-07 14:24 ` [PATCH 5.10.y-cip 22/25] drm: [HACK DO NOT APPLY] add drmm_encoder_alloc() Biju Das
2023-12-07 14:25 ` [PATCH 5.10.y-cip 23/25] drm: [HACK DO NOT APPLY] Allow const struct drm_driver Biju Das
2023-12-07 14:25 ` [PATCH 5.10.y-cip 24/25] drm: [HACK DO NOT APPLY] Add RZ/G2L DU Support Biju Das
2023-12-07 14:25 ` [PATCH 5.10.y-cip 25/25] defconfig: [HACK DO NOT APPLY] Enable display on RZ/G2L SMARC EVK Biju Das
2023-12-07 19:41 ` [PATCH 5.10.y-cip 00/25] Add RZ/G2L DSI support Pavel Machek
2023-12-08 11:38 ` Pavel Machek
2023-12-08 12:09   ` Biju Das
     [not found]   ` <179ED9F671D9670E.16398@lists.cip-project.org>
2023-12-08 12:56     ` [cip-dev] " Biju Das

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20231207142502.401651-2-biju.das.jz@bp.renesas.com \
    --to=biju.das.jz@bp.renesas.com \
    --cc=cip-dev@lists.cip-project.org \
    --cc=nobuhiro1.iwamatsu@toshiba.co.jp \
    --cc=pavel@denx.de \
    --cc=prabhakar.mahadev-lad.rj@bp.renesas.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.